Struct ShaderFill
pub struct ShaderFill { /* private fields */ }Implementations
impl ShaderFill
impl ShaderFill
pub fn new<F>( sksl: impl Into<Arc<str>>, effect: RCHandle<SkRuntimeEffect>, provider: F, ) -> ShaderFill
pub fn from_provider<S>(
sksl: impl Into<Arc<str>>,
effect: RCHandle<SkRuntimeEffect>,
provider: S,
) -> ShaderFillwhere
S: ShaderProvider + 'static,
pub fn prepare_shader(
&self,
bounds: Rect<f32, ()>,
) -> Option<RCHandle<SkShader>>
pub fn prepare_shader( &self, bounds: Rect<f32, ()>, ) -> Option<RCHandle<SkShader>>
Prepare the shader for use by providing the necessary uniforms. Returns None if the provider could not produce a [Shader], in which case the renderer will fallback to no fill.